****************************
Mopidy-FM
****************************

.. image:: https://img.shields.io/pypi/v/Mopidy-FM
    :target: https://pypi.org/project/Mopidy-FM/
    :alt: Latest PyPI version

.. image:: https://img.shields.io/github/workflow/status/jrsmile/mopidy-fm/CI
    :target: https://github.com/jrsmile/mopidy-fm/actions
    :alt: CI build status

.. image:: https://img.shields.io/codecov/c/gh/jrsmile/mopidy-fm
    :target: https://codecov.io/gh/jrsmile/mopidy-fm
    :alt: Test coverage

Mopidy extension for pifmadv Radio


Installation
============

Install by running::

    python3 -m pip install Mopidy-FM

See https://mopidy.com/ext/fm/ for alternative installation methods.


Configuration
=============

Before starting Mopidy, you must add configuration for
Mopidy-FM to your Mopidy configuration file::

    [fm]
    # TODO: Add example of extension config


Project resources
=================

- `Source code <https://github.com/jrsmile/mopidy-fm>`_
- `Issue tracker <https://github.com/jrsmile/mopidy-fm/issues>`_
- `Changelog <https://github.com/jrsmile/mopidy-fm/blob/master/CHANGELOG.rst>`_


Credits
=======

- Original author: `JRSmile <https://github.com/jrsmile>`__
- Current maintainer: `JRSmile <https://github.com/jrsmile>`__
- `Contributors <https://github.com/jrsmile/mopidy-fm/graphs/contributors>`_
